==> lambdaeventbridge-1.168.0-sources.jar: software/amazon/awsconstructs/services/lambdaeventbridge/LambdaToEventbridge.java <==
package software.amazon.awsconstructs.services.lambdaeventbridge;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.65.0 (build 7a02b7f)", date = "2022-08-22T21:35:51.520Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaeventbridge.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-eventbridge.LambdaToEventbridge")
public class LambdaToEventbridge extends software.amazon.awscdk.core.Construct {

    protected LambdaToEventbridge(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToEventbridge(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToEventbridge(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.events.IEventBus getEventBus() {
        return software.amazon.jsii.Kernel.get(this, "eventBus", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.IEventBus.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the Event bus.
         * <p>
         * Default: - EVENTBUS_NAME
         * <p>
         * @return {@code this}
         * @param eventBusEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the Event bus. This parameter is required.
         */
        public Builder eventBusEnvironmentVariableName(final java.lang.String eventBusEnvironmentVariableName) {
            this.props.eventBusEnvironmentVariableName(eventBusEnvironmentVariableName);
            return this;
        }

        /**
         * A new custom EventBus is created with provided props.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventBusProps A new custom EventBus is created with provided props. This parameter is required.
         */
        public Builder eventBusProps(final software.amazon.awscdk.services.events.EventBusProps eventBusProps) {
            this.props.eventBusProps(eventBusProps);
            return this;
        }

        /**
         * Existing instance of a custom EventBus.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingEventBusInterface Existing instance of a custom EventBus. This parameter is required.
         */
        public Builder existingEventBusInterface(final software.amazon.awscdk.services.events.IEventBus existingEventBusInterface) {
            this.props.existingEventBusInterface(existingEventBusInterface);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge build() {
            return new software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdaeventbridge-2.63.0-sources.jar: software/amazon/awsconstructs/services/lambdaeventbridge/LambdaToEventbridge.java <==
package software.amazon.awsconstructs.services.lambdaeventbridge;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.101.0 (build b95fe5d)", date = "2024-07-19T19:25:12.152Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdaeventbridge.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-eventbridge.LambdaToEventbridge")
public class LambdaToEventbridge extends software.constructs.Construct {

    protected LambdaToEventbridge(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToEventbridge(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public LambdaToEventbridge(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.events.IEventBus getEventBus() {
        return software.amazon.jsii.Kernel.get(this, "eventBus", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.events.IEventBus.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridgeProps.Builder();
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Optional Name for the Lambda function environment variable set to the name of the Event bus.
         * <p>
         * Default: - EVENTBUS_NAME
         * <p>
         * @return {@code this}
         * @param eventBusEnvironmentVariableName Optional Name for the Lambda function environment variable set to the name of the Event bus. This parameter is required.
         */
        public Builder eventBusEnvironmentVariableName(final java.lang.String eventBusEnvironmentVariableName) {
            this.props.eventBusEnvironmentVariableName(eventBusEnvironmentVariableName);
            return this;
        }

        /**
         * A new custom EventBus is created with provided props.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param eventBusProps A new custom EventBus is created with provided props. This parameter is required.
         */
        public Builder eventBusProps(final software.amazon.awscdk.services.events.EventBusProps eventBusProps) {
            this.props.eventBusProps(eventBusProps);
            return this;
        }

        /**
         * Existing instance of a custom EventBus.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingEventBusInterface Existing instance of a custom EventBus. This parameter is required.
         */
        public Builder existingEventBusInterface(final software.amazon.awscdk.services.events.IEventBus existingEventBusInterface) {
            this.props.existingEventBusInterface(existingEventBusInterface);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge build() {
            return new software.amazon.awsconstructs.services.lambdaeventbridge.LambdaToEventbridge(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
